import os, sys

from bs4 import BeautifulSoup
from urllib.parse import unquote

from RAAspotter import RAAspotter

class RAAspotter_pref13(RAAspotter):

  # Config
  __HOST       = 'https://www.bouches-du-rhone.gouv.fr'
  __RAA_PAGE   = f'{__HOST}/Publications/RAA-et-Archives'
  __USER_AGENT = 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/122.0.0.0 Safari/537.36'

  def __init__(self, data_dir):
    super().__init__(data_dir, self.__USER_AGENT)
    self.enable_tor(10)

  def get_raa(self, keywords):
    self.print_output('RAAspotter_pref13')
    self.print_output(f'Termes recherchés: {keywords}')

    page_content = self.get_page(self.__RAA_PAGE).content
    sub_pages = self.get_sub_pages(page_content, 'div.fr-card__body div.fr-card__content h2.fr-card__title a', self.__HOST)
    raa_elements = []
    for page in sub_pages:
      for element in self.get_raa_elements(self.get_page(page).content):
        raa_elements.append(element)
    self.parse_raa(raa_elements, keywords.split(','))

  def get_raa_elements(self, page_content):
    elements = []
    # On charge le parser
    soup = BeautifulSoup(page_content, 'html.parser')

    # Pour chaque balise a, on regarde si c'est un PDF, et si oui on le parse
    for a in soup.find_all('a', href=True):
      if a['href'].endswith('.pdf'):
        if a['href'].startswith('/'):
          url = f"{self.__HOST}{a['href']}"
        else:
          url = a['href']

        name     = unquote(url.split('/')[-1])
        date     = "date non renseignée"
        filename = unquote(url.split('/')[-1])

        raa = RAAspotter.RAA(url, date, name, filename)
        elements.append(raa)
    return elements
